==> cxf-testutils-2.0.6.13-fuse-sources.jar: org/apache/type_test/types2/OccuringChoiceWithAnyAttribute.java <==

package org.apache.type_test.types2;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAnyAttribute;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlElements;
import javax.xml.bind.annotation.XmlType;
import javax.xml.namespace.QName;


/**
 * <p>Java class for OccuringChoiceWithAnyAttribute complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="OccuringChoiceWithAnyAttribute">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;choice maxOccurs="5">
 *         &lt;element name="varString" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *         &lt;element name="varInt" type="{http://www.w3.org/2001/XMLSchema}int"/>
 *       &lt;/choice>
 *       &lt;attribute name="AtInt" type="{http://www.w3.org/2001/XMLSchema}int" />
 *       &lt;attribute name="AtString" type="{http://www.w3.org/2001/XMLSchema}string" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "OccuringChoiceWithAnyAttribute", propOrder = {
    "varStringOrVarInt"
})
public class OccuringChoiceWithAnyAttribute {

    @XmlElements({
        @XmlElement(name = "varInt", namespace = "http://apache.org/type_test/types2", required = true, type = Integer.class),
        @XmlElement(name = "varString", namespace = "http://apache.org/type_test/types2", required = true, type = String.class)
    })
    protected List<Serializable> varStringOrVarInt;
    @XmlAttribute(name = "AtInt")
    protected Integer atInt;
    @XmlAttribute(name = "AtString")
    protected String atString;
    @XmlAnyAttribute
    private Map<QName, String> otherAttributes = new HashMap<QName, String>();

    /**
     * Gets the value of the varStringOrVarInt property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the varStringOrVarInt property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getVarStringOrVarInt().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link Integer }
     * {@link String }
     * 
     * 
     */
    public List<Serializable> getVarStringOrVarInt() {
        if (varStringOrVarInt == null) {
            varStringOrVarInt = new ArrayList<Serializable>();
        }
        return this.varStringOrVarInt;
    }

    /**
     * Gets the value of the atInt property.
     * 
     * @return
     *     possible object is
     *     {@link Integer }
     *     
     */
    public Integer getAtInt() {
        return atInt;
    }

    /**
     * Sets the value of the atInt property.
     * 
     * @param value
     *     allowed object is
     *     {@link Integer }
     *     
     */
    public void setAtInt(Integer value) {
        this.atInt = value;
    }

    /**
     * Gets the value of the atString property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getAtString() {
        return atString;
    }

    /**
     * Sets the value of the atString property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setAtString(String value) {
        this.atString = value;
    }

    /**
     * Gets a map that contains attributes that aren't bound to any typed property on this class.
     * 
     * <p>
     * the map is keyed by the name of the attribute and 
     * the value is the string value of the attribute.
     * 
     * the map returned by this method is live, and you can add new attribute
     * by updating the map directly. Because of this design, there's no setter.
     * 
     * 
     * @return
     *     always non-null
     */
    public Map<QName, String> getOtherAttributes() {
        return otherAttributes;
    }

}

==> cxf-testutils-2.0.6.16-fuse-sources.jar: org/apache/type_test/types2/OccuringChoiceWithAnyAttribute.java <==

package org.apache.type_test.types2;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAnyAttribute;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlElements;
import javax.xml.bind.annotation.XmlType;
import javax.xml.namespace.QName;


/**
 * <p>Java class for OccuringChoiceWithAnyAttribute complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="OccuringChoiceWithAnyAttribute">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;choice maxOccurs="5">
 *         &lt;element name="varString" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *         &lt;element name="varInt" type="{http://www.w3.org/2001/XMLSchema}int"/>
 *       &lt;/choice>
 *       &lt;attribute name="AtInt" type="{http://www.w3.org/2001/XMLSchema}int" />
 *       &lt;attribute name="AtString" type="{http://www.w3.org/2001/XMLSchema}string" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "OccuringChoiceWithAnyAttribute", propOrder = {
    "varStringOrVarInt"
})
public class OccuringChoiceWithAnyAttribute {

    @XmlElements({
        @XmlElement(name = "varString", namespace = "http://apache.org/type_test/types2", required = true, type = String.class),
        @XmlElement(name = "varInt", namespace = "http://apache.org/type_test/types2", required = true, type = Integer.class)
    })
    protected List<Serializable> varStringOrVarInt;
    @XmlAttribute(name = "AtInt")
    protected Integer atInt;
    @XmlAttribute(name = "AtString")
    protected String atString;
    @XmlAnyAttribute
    private Map<QName, String> otherAttributes = new HashMap<QName, String>();

    /**
     * Gets the value of the varStringOrVarInt property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the varStringOrVarInt property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getVarStringOrVarInt().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link String }
     * {@link Integer }
     * 
     * 
     */
    public List<Serializable> getVarStringOrVarInt() {
        if (varStringOrVarInt == null) {
            varStringOrVarInt = new ArrayList<Serializable>();
        }
        return this.varStringOrVarInt;
    }

    /**
     * Gets the value of the atInt property.
     * 
     * @return
     *     possible object is
     *     {@link Integer }
     *     
     */
    public Integer getAtInt() {
        return atInt;
    }

    /**
     * Sets the value of the atInt property.
     * 
     * @param value
     *     allowed object is
     *     {@link Integer }
     *     
     */
    public void setAtInt(Integer value) {
        this.atInt = value;
    }

    /**
     * Gets the value of the atString property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getAtString() {
        return atString;
    }

    /**
     * Sets the value of the atString property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setAtString(String value) {
        this.atString = value;
    }

    /**
     * Gets a map that contains attributes that aren't bound to any typed property on this class.
     * 
     * <p>
     * the map is keyed by the name of the attribute and 
     * the value is the string value of the attribute.
     * 
     * the map returned by this method is live, and you can add new attribute
     * by updating the map directly. Because of this design, there's no setter.
     * 
     * 
     * @return
     *     always non-null
     */
    public Map<QName, String> getOtherAttributes() {
        return otherAttributes;
    }

}
